@@ -1,5 +1,9 @@
 package Dancer2::Plugin::PageHistory;
 use utf8;
+use strict;
+use warnings;
+
+=encoding utf8
 
 =head1 NAME
 
@@ -7,11 +11,11 @@ Dancer2::Plugin::PageHistory - store recent page history for user into session
 
 =head1 VERSION
 
-Version 0.203
+Version 0.204
 
 =cut
 
-our $VERSION = '0.203';
+our $VERSION = '0.204';
 
 use Dancer2::Core::Types qw/Bool HashRef Str/;
 use Dancer2::Plugin;
